@@ -1,16 +1,21 @@
-#' Create a description object for a parameter of a machine learning algorithm.
+#' @title Create a description object for a parameter of a machine learning algorithm.
 #'
+#' @description
 #' This specializes \code{\link{Param}} by adding a few more attributes,
 #' like a default value, whether it refers to a training or a predict function, etc.
+#' Note that you can set \code{length} to \code{NA}
 #'
 #' The S3 class is a \code{\link{Param}} which additionally stores these elements:
 #' \describe{
-#' \item{default [any]}{See argument of same name.}
-#' \item{has.default [\code{logical(1)}]}{Was a default value provided?}
 #' \item{when [\code{character(1)}]}{See argument of same name.}
 #' }
 #'
+#' See the note in \code{\link{Param}} about being able to pass expressions to certain arguments.
+#'
 #' @inheritParams Param
+#' @param len [\code{integer(1)}]\cr
+#'   Length of vector parameter.
+#'   Can be set to \code{NA} to define a vector with unspecified length.
 #' @param when [\code{character(1)}]\cr
 #'   Specifies when parameter is used in the learner: \dQuote{train}, \dQuote{predict} or \dQuote{both}.
 #'   Default is \dQuote{train}.
@@ -20,6 +25,7 @@
 NULL
 
 makeLearnerParam = function(p, when) {
+  assertChoice(when, c("train", "predict", "both"))
   p$when = when
   class(p) = c("LearnerParam", "Param")
   return(p)
