@@ -114,7 +114,7 @@ print.OptPath = function(x, ...) {
     s = ""
   } else {
     ntimes = sum(!is.na(et))
-    ntime.nas = sum(is.na(et))
+    ntime.nas = length(et) - ntimes
     # no non-na exec times in path
     if (ntimes == 0L) {
       et1 = 0
@@ -126,9 +126,9 @@ print.OptPath = function(x, ...) {
     s = sprintf(" Range: %g - %g. %i NAs.", et1, et2, ntime.nas)
   }
   catf("  Exec times: %s.%s", !is.null(et), s)
-  if (!is.null(ex))
-  catf("  Extras: %i columns", ifelse(length(ex) > 0L, length(ex[[1]]), NA))
+  if (!is.null(ex)) {
+    nondot.extra.length = ifelse(length(ex) > 0L,
+        length(removeDotEntries(ex[[1L]])), NA)
+    catf("  Extras: %i columns", nondot.extra.length)
+  }
 }
-
-
-
