@@ -3,31 +3,45 @@
 #' @description
 #' For each parameter type a special constructor function is available, see below.
 #'
+#' For the following arguments you can also pass an \code{expression} instead of a concrete value:
+#' \code{default}, \code{len}, \code{lower}, \code{upper}, \code{values}.
+#' These expressions can depend on arbitrary symbols, which are later filled in / substituted from
+#' a dictionary, in order to produce a concrete valu, see \code{\link{evaluateParamExpressions}}.
+#' So this enables data / context dependent settings, which is sometimes useful.
+#'
 #' The S3 class is a list which stores these elements:
 #' \describe{
 #'   \item{id [\code{character(1)}]}{See argument of same name.}
-#'   \item{type [\code{character(1)}]}{Data type of parameter. Possible types are \dQuote{numeric}, \dQuote{numericvector}, \dQuote{integer}, \dQuote{integervector}, \dQuote{logical}, \dQuote{logicalvector}, \dQuote{discrete}, \dQuote{discretevector}, \dQuote{function}, \dQuote{untyped}.}
-#'   \item{len [\code{integer(1)}]}{See argument of same name.}
-#'   \item{lower [\code{numeric}]}{See argument of same name. Length of this vector is \code{len}.}
-#'   \item{upper [\code{numeric}]}{See argument of same name. Length of this vector is \code{len}.}
-#'   \item{values [\code{list}]}{Discrete values, always stored as a named list.}
+#'   \item{type [\code{character(1)}]}{Data type of parameter. For all type string see \code{\link{getTypeStringsAll}}}
+#'   \item{len [\code{integer(1)} | \code{expression}]}{See argument of same name.}
+#'   \item{lower [\code{numeric} | \code{expression}]}{See argument of same name. Length of this vector is \code{len}.}
+#'   \item{upper [\code{numeric} | \code{expression}]}{See argument of same name. Length of this vector is \code{len}.}
+#'   \item{values [\code{list} | \code{expression}]}{Discrete values, always stored as a named list.}
+#'   \item{cnames [\code{character}}{See argument of same name.}
+#'   \item{allow.inf [\code{logical(1)}]}{See argument of same name.}
 #'   \item{trafo [\code{NULL} | \code{function(x)}]}{See argument of same name.}
 #'   \item{requires [\code{NULL} | \code{expression}]}{See argument of same name.}
+#'   \item{default [any concrete value | \code{expression}]}{See argument of same name.}
+#'   \item{has.default [\code{logical(1)}]}{Extra flag to really be able to check whether the user passed a default, to avoid troubles with \code{NULL} and \code{NA}.}
+#'   \item{tunable [\code{logical(1)}]}{See argument of same name.}
+#'   \item{special.vals [\code{list}]}{See argument of same name.}
 #' }
 #'
 #' @param id [\code{character(1)}]\cr
 #'   Name of parameter.
-#' @param len [\code{integer(1)}]\cr
+ #' @param len [\code{integer(1)} | \code{expression}]\cr
 #'   Length of vector parameter.
-#' @param lower [\code{numeric}]\cr
+#' @param lower [\code{numeric} | \code{expression}]\cr
 #'   Lower bounds.
 #'   A singe value of length 1 is automatically replicated to \code{len} for vector parameters.
+#'   If \code{len = NA} you can only pass length-1 scalars.
 #'   Default is \code{-Inf}.
-#' @param upper [\code{numeric}]\cr
+#' @param upper [\code{numeric} | \code{expression}]\cr
 #'   Upper bounds.
 #'   A singe value of length 1 is automatically replicated to \code{len} for vector parameters.
+#'   If \code{len = NA} you can only pass length-1 scalars.
 #'   Default is \code{Inf}.
-#' @param values [\code{vector} | \code{list}]\cr
+#' @param values [\code{vector} | \code{list} | \code{expression}]\cr
 #'   Possible discrete values. Instead of using a vector of atomic values,
 #'   you are also allowed to pass a list of quite \dQuote{complex} R objects,
 #'   which are used as discrete choices. If you do the latter,
@@ -40,8 +54,9 @@
 #' @param allow.inf [\code{logical(1)}]\cr
 #'   Allow infinite values for numeric and numericvector params to be feasible settings.
 #'   Default is \code{FALSE}.
-#' @param default [any]\cr
+#' @param default [any concrete value | \code{expression}]\cr
 #'   Default value used in learner.
+#'   Note: When this is a discrete parameter make sure to use a VALUE here, not the NAME of the value.
 #'   If this argument is missing, it means no default value is available.
 #' @param trafo [\code{NULL} | \code{function(x)}]\cr
 #'   Function to transform parameter. It should be applied to the parameter value
@@ -77,9 +92,35 @@
 #' makeCharacterParam("z")
 NULL
 
-makeParam = function(id, type, len, lower, upper, values, cnames, allow.inf = FALSE, default,
-  trafo = NULL, requires = NULL, tunable = TRUE, special.vals = list()) {
+makeParam = function(id, type, learner.param, len = 1L, lower = NULL, upper = NULL, values = NULL, cnames = NULL, allow.inf = FALSE, default,
+  trafo = NULL, requires = NULL, tunable = TRUE, special.vals = list(), when) {
   assertString(id)
+  assert(
+    checkCount(len, na.ok = learner.param),
+    checkClass(len, "expression")
+  )
+  if (isNumericTypeString(type, include.int = TRUE)) {
+    assert(
+      checkNumeric(lower, any.missing = FALSE),
+      checkClass(lower, "expression")
+    )
+    assert(
+      checkNumeric(upper, any.missing = FALSE),
+      checkClass(upper, "expression")
+    )
+    # the following check also ensures that if len=NA, the lower and upper must be scalars
+    if (!is.expression(len) && !is.expression(lower)) {
+      if (length(lower) %nin% c(1L, len))
+        stopf("For param '%s' length 'lower' must be either 1 or length of param, not: %i", id, length(lower))
+    }
+    if (!is.expression(len) && !is.expression(upper)) {
+      if (length(upper) %nin% c(1L, len))
+        stopf("For param '%s' length 'upper' must be either 1 or length of param, not: %i", id, length(upper))
+    }
+  }
+  if (isDiscreteTypeString(type)) {
+    values = checkValuesForDiscreteParam(id, values)
+  }
   #We cannot check default} for NULL or NA as this could be the default value!
   if (missing(default)) {
     has.default = FALSE
@@ -97,6 +138,19 @@ makeParam = function(id, type, len, lower, upper, values, cnames, allow.inf = FA
     assertClass(requires, "call")
   }
   assertList(special.vals)
+
+  if (isNumericTypeString(type, include.int = TRUE)) {
+    if (!is.expression(len) && !is.na(len) && len > 1L) {
+      if (isScalarNumeric(lower))
+        lower = rep(lower, len)
+      if (isScalarNumeric(upper))
+        upper = rep(upper, len)
+    }
+    if (!is.expression(lower) && !is.expression(upper)) {
+     if (any(upper < lower))
+        stopf("For param '%s' some component of 'upper' is smaller than the corresponding one in 'lower'", id)
+    }
+  }
   p = makeS3Obj("Param",
     id = id,
     type = type,
@@ -113,8 +167,12 @@ makeParam = function(id, type, len, lower, upper, values, cnames, allow.inf = FA
     tunable = tunable,
     special.vals = special.vals
   )
-  if (has.default && !isFeasible(p, default))
-    stop(p$id, " : 'default' must be a feasible parameter setting.")
+  if (learner.param)
+    p = makeLearnerParam(p, when)
+  if (has.default && !is.expression(default)) {
+    if (!isFeasible(p, default))
+      stop(p$id, " : 'default' must be a feasible parameter setting.")
+  }
   return(p)
 }
 
@@ -169,3 +227,46 @@ getParPrintData = function(x, trafo = TRUE, used = TRUE, constr.clip = 40L) {
 print.Param = function(x, ..., trafo = TRUE) {
   print(getParPrintData(x, trafo = trafo))
 }
+
+# helper function to perform sanity checks on values of disctrete param
+checkValuesForDiscreteParam = function(id, values) {
+  if (is.vector(values) && !is.expression(values))
+    values = as.list(values)
+  assert(
+    checkList(values),
+    checkClass(values, "expression")
+  )
+  if (!is.expression(values)) {
+    if (length(values) == 0L)
+      stopf("No possible value for discrete parameter %s!", id)
+
+    # check that NA does not occur in values, we use that for "missing state" for dependent params
+    # make sure that this works for complex object too, cannot be done with simple is.na
+    if (any(vlapply(values, isScalarNA)))
+      stopf("NA is not allowed as a value for discrete parameter %s.\nParamHelpers uses NA as a special value for dependent parameters.", id)
+
+    n = length(values)
+    ns = names(values)
+    # if names missing, set all to ""
+    if (is.null(ns))
+      ns = rep("", n)
+    # guess missing names
+    for (i in seq_len(n)) {
+      v = values[[i]]
+      if(is.na(ns[i]) || ns[i] == "") {
+        if (is.character(v) || is.numeric(v))
+          ns[i] = as.character(v)
+      }
+    }
+    names(values) = ns
+    if (!isProperlyNamed(values)) {
+      stopf("Not all values for parameter '%s' were named and names could not be guessed!", id)
+    }
+
+    # check that NA does not occur in value names, see above
+    if ("NA" %in% names(values))
+      stopf("NA is not allowed as a value name for discrete parameter %s.\nParamHelpers uses NA as a special value for dependent parameters.", id)
+  }
+  return(values)
+}
+
