@@ -29,8 +29,8 @@
 #'   \item{We create a space filling design for all parameters, disregarding \code{requires},
 #'     a \code{trafo} or the forbidden region.}
 #'   \item{Forbidden points are removed.}
-#'   \item{Parameters are trafoed (maybe); dependent parameters whose constraints are unsatisfied
-#'     are set to \code{NA} entries.}
+#'   \item{Parameters are trafoed (potentially, depending on the setting of argument \code{trafo});
+#'     dependent parameters whose constraints are unsatisfied are set to \code{NA} entries.}
 #'   \item{Duplicated design points are removed. Duplicated points are not generated in a
 #'    reasonable space-filling design, but the way discrete parameters and also parameter dependencies
 #'    are handled make this possible.}
@@ -41,9 +41,14 @@
 #' Note that augmenting currently is somewhat experimental as we simply generate missing points
 #' via new calls to \code{\link[lhs]{randomLHS}}, but do not add points so they are maximally
 #' far away from the already present ones. The reason is that the latter is quite hard to achieve
-#' with complicated dependences and forbidden regions, if one wants to ensure that points actually
+#' with complicated dependencies and forbidden regions, if one wants to ensure that points actually
 #' get added... But we are working on it.
 #'
+#' Note that if you have trafos attached to your params, the complete creation of the design
+#' (except for the detection of invalid parameters w.r.t to their \code{requires} setting)
+#' takes place on the UNTRANSFORMED scale. So this function creates, e.g., a maximin LHS
+#' design on the UNTRANSFORMED scale, but not necessarily the transformed scale.
+#'
 #' \code{generateDesign} will NOT work if there are dependencies over multiple levels of
 #' parameters and the dependency is only given with respect to the \dQuote{previous} parameter.
 #' A current workaround is to state all dependencies on all parameters involved.
@@ -123,11 +128,10 @@ generateDesign = function(n = 10L, par.set, fun, fun.args = list(), trafo = FALS
 
 
   nmissing = n
-  iter = 0
   # result objects
   res = data.frame()
   des = matrix(nrow = 0, ncol = k)
-  repeat {
+  for (iter in seq_len(augment)) {
     ### get design, types converted, trafos, conditionals set to NA
     # create new design or augment if we already have some points
     newdes = if (nmissing == n)
@@ -141,7 +145,9 @@ generateDesign = function(n = 10L, par.set, fun, fun.args = list(), trafo = FALS
     # check each row if forbidden, then remove
     if (hasForbidden(par.set)) {
       #FIXME: this is pretty slow, but correct
-      fb = rowSapply(newres, isForbidden, par.set = par.set)
+      fb = unlist(lapply(dfRowsToList(newres, par.set = par.set), function(x) {
+        isForbidden(x, par.set = par.set)
+      }))
       newres = newres[!fb, , drop = FALSE]
       newdes = newdes[!fb, , drop = FALSE]
     }
@@ -155,9 +161,8 @@ generateDesign = function(n = 10L, par.set, fun, fun.args = list(), trafo = FALS
     res = res[!to.remove, , drop = FALSE]
     nmissing = n - nrow(res)
 
-    # enough points or augment tries? we are done!
-    iter = iter + 1L
-    if (nmissing == 0L || iter >= augment)
+    # Enough points? We are done!
+    if (nmissing == 0L)
       break
   }
 
