@@ -17,12 +17,17 @@
 #' \enumerate{
 #'   \item{We create a grid. For numerics and integers we use the specfied resolution. For discretes all values will be taken.}
 #'   \item{Forbidden points are removed.}
-#'   \item{Parameters are trafoed (maybe); dependent parameters whose constraints are unsatisfied
-#'     are set to \code{NA} entries.}
+#'   \item{Parameters are trafoed (potentially, depending on the setting of argument \code{trafo});
+#'   dependent parameters whose constraints are unsatisfied are set to \code{NA} entries.}
 #'   \item{Duplicated points are removed. Duplicated points are not generated in a
 #'    grid design, but the way parameter dependencies are handled make this possible.}
 #' }
 #'
+#' Note that if you have trafos attached to your params, the complete creation of the design
+#' (except for the detection of invalid parameters w.r.t to their \code{requires} setting)
+#' takes place on the UNTRANSFORMED scale. So this function creates a regular grid
+#' over the param space on the UNTRANSFORMED scale, but not necessarily the transformed scale.
+#'
 #' \code{generateDesign} will NOT work if there are dependencies over multiple levels of
 #' parameters and the dependency is only given with respect to the \dQuote{previous} parameter.
 #' A current workaround is to state all dependencies on all parameters involved.
@@ -43,16 +48,14 @@
 #' )
 #' generateGridDesign(ps, resolution = c(x1 = 4, x2 = 5), trafo = TRUE)
 generateGridDesign = function(par.set, resolution, trafo = FALSE) {
-  z = doBasicGenDesignChecks(par.set)
+  doBasicGenDesignChecks(par.set)
 
-  ids = getParamIds(par.set)
   pars = par.set$pars
   n = length(pars)
   lens = getParamLengths(par.set)
   m = sum(lens)
-  pids1 = getParamIds(par.set)
-  pids2 = getParamIds(par.set, repeated = TRUE, with.nr = TRUE)
-  par.set.num = filterParams(par.set = par.set, type = getNumericTypes())
+  pids = getParamIds(par.set, repeated = TRUE, with.nr = TRUE)
+  par.set.num = filterParamsNumeric(par.set, include.int = TRUE)
   pids.num = getParamIds(par.set.num)
 
   if (hasNumeric(par.set, include.int = TRUE)) {
@@ -67,13 +70,12 @@ generateGridDesign = function(par.set, resolution, trafo = FALSE) {
 
   assertFlag(trafo)
 
-  vals.list = setNames(vector("list", m), pids2)
+  vals.list = setNames(vector("list", m), pids)
   el.counter = 1L
 
   # iterate over all params and discretize them
-  for (i in 1:n) {
+  for (i in seq_len(n)) {
     p = pars[[i]]
-    type = p$type
     if (isNumeric(p)) {
       lower = p$lower
       upper = p$upper
@@ -83,7 +85,7 @@ generateGridDesign = function(par.set, resolution, trafo = FALSE) {
     }
 
     # iterate over vector elements and d
-    for (j in 1:p$len) {
+    for (j in seq_len(p$len)) {
       if (isDiscrete(p, include.logical = FALSE)) {
         newvals = names(discvals)
       } else if (isLogical(p)) {
@@ -108,7 +110,7 @@ generateGridDesign = function(par.set, resolution, trafo = FALSE) {
   # log(vec): logical
   # dis(vec): character
 
-  colnames(res) = pids2
+  colnames(res) = pids
 
   # check each row if forbidden, then remove
   if (hasForbidden(par.set)) {
