@@ -9,24 +9,30 @@
 #'  logical(vector)   \tab  \code{logical}
 #' }
 #' If you want to convert these, look at \code{\link[BBmisc]{convertDataFrameCols}}.
-#' Dependent parameters whose constraints are unsatisfied generate \code{NA} entries in their
-#' respective columns.
 #' For discrete vectors the levels and their order will be preserved, even if not all levels are present.
 #'
 #' The algorithm simply calls \code{\link{sampleValues}} and arranges the result in a data.frame.
 #'
+#' Parameters are trafoed (potentially, depending on the setting of argument \code{trafo});
+#' dependent parameters whose constraints are unsatisfied are set to \code{NA} entries.
+#'
 #' \code{generateRandomDesign} will NOT work if there are dependencies over multiple levels of
 #' parameters and the dependency is only given with respect to the \dQuote{previous} parameter.
 #' A current workaround is to state all dependencies on all parameters involved.
 #' (We are working on it.)
 #'
+#' Note that if you have trafos attached to your params, the complete creation of the design
+#' (except for the detection of invalid parameters w.r.t to their \code{requires} setting)
+#' takes place on the UNTRANSFORMED scale. So this function samples from a uniform density
+#' over the param space on the UNTRANSFORMED scale, but not necessarily the transformed scale.
+#'
 #' @template arg_gendes_n
 #' @template arg_parset
 #' @template arg_trafo
 #' @template ret_gendes_df
 #' @export
 generateRandomDesign = function(n = 10L, par.set, trafo = FALSE) {
-  z = doBasicGenDesignChecks(par.set)
+  doBasicGenDesignChecks(par.set)
   des = sampleValues(par.set, n, discrete.names = TRUE, trafo = trafo)
 
   # FIXME: all next lines are sloooow in R I guess. C?
@@ -47,8 +53,3 @@ generateRandomDesign = function(n = 10L, par.set, trafo = FALSE) {
   attr(des, "trafo") = trafo
   return(des)
 }
-
-
-
-
-
