@@ -39,10 +39,14 @@ getParamIds.Param = function(par, repeated = FALSE, with.nr = FALSE) {
   pid = par$id
   if (repeated && isVector(par)) {
     n = par$len
-    if (n > 1 && with.nr)
-      paste(rep(pid, n), 1:n, sep = "")
-    else
-      rep(pid, n)
+    if (!is.na(n)) {
+      if (n > 1L && with.nr)
+        paste(rep(pid, n), seq_len(n), sep = "")
+      else
+        rep(pid, n)
+    } else {
+      pid
+    }
   } else {
     pid
   }
