@@ -8,6 +8,14 @@
 #' @rdname getTypeStrings
 NULL
 
+#' @export
+#' @rdname getTypeStrings
+getTypeStringsAll = function() {
+  c("numeric", "integer", "numericvector", "integervector", "discrete",
+    "discretevector", "logical", "logicalvector", "character", "charactervector",
+    "function", "untyped")
+}
+
 #' @export
 #' @rdname getTypeStrings
 getTypeStringsNumeric = function(include.int = TRUE) {
@@ -29,6 +37,12 @@ getTypeStringsInteger = function() {
   c("integer", "integervector")
 }
 
+#' @export
+#' @rdname getTypeStrings
+getTypeStringsCharacter = function() {
+  c("character", "charactervector")
+}
+
 #' @export
 #' @rdname getTypeStrings
 getTypeStringsDiscrete = function(include.logical = TRUE) {
@@ -38,3 +52,9 @@ getTypeStringsDiscrete = function(include.logical = TRUE) {
     c("discrete", "discretevector")
 }
 
+#' @export
+#' @rdname getTypeStrings
+getTypeStringsLogical = function() {
+  c("logical", "logicalvector")
+}
+
